Lists the source archive and canonical cleaned datasets currently stored in the package cache. Merely inspecting the cache does not create any files or directories.
Value
A tibble with the cache entry type, dataset, absolute path, size in MiB and modification time. Returns an empty tibble when the cache is empty.