Returns a small tibble describing the datasets that read_infosiga() can
import, including their grain (what one row represents) and key columns.
Value
A tibble with columns dataset, description,
grain and keys.
Examples
infosiga_datasets()
#> # A tibble: 3 × 4
#> dataset description grain keys
#> <chr> <chr> <chr> <chr>
#> 1 sinistros Traffic crash events recorded in the state of Sao Paulo. one … id_s…
#> 2 pessoas People (victims) involved in traffic crashes. one … id_p…
#> 3 veiculos Vehicles involved in traffic crashes. one … id_v…